@@ -1015,17 +1015,8 @@ bool samplv1_jack_application::setup (void)
 
 	m_pSampl = new samplv1_jack(client_name);
 
-	if (m_bGui) {
+	if (m_bGui)
 		m_pWidget = new samplv1widget_jack(m_pSampl);
-	//	m_pWidget->show();
-		if (m_presets.isEmpty())
-			m_pWidget->initPreset();
-		else
-			m_pWidget->loadPreset(m_presets.first());
-	}
-	else
-	if (!m_presets.isEmpty())
-		samplv1_param::loadPreset(m_pSampl, m_presets.first());
 
 #ifdef CONFIG_NSM
 	// Check whether to participate into a NSM session...
@@ -1054,8 +1045,16 @@ bool samplv1_jack_application::setup (void)
 	}
 	else
 #endif	// CONFIG_NSM
-	if (m_pWidget)
+	if (m_pWidget) {
 		m_pWidget->show();
+		if (m_presets.isEmpty())
+			m_pWidget->initPreset();
+		else
+			m_pWidget->loadPreset(m_presets.first());
+	}
+	else
+	if (!m_presets.isEmpty())
+		samplv1_param::loadPreset(m_pSampl, m_presets.first());
 
 	// Start watchdog timer...
 	watchdog_start();
@@ -1104,9 +1103,9 @@ void samplv1_jack_application::openSession (void)
 
 	bool bOpen = false;
 
-	QFileInfo fi(path_name, "session." PROJECT_NAME);
+	QFileInfo fi(path_name, display_name + '.' + PROJECT_NAME);
 	if (!fi.exists())
-		fi.setFile(path_name, display_name + '.' + PROJECT_NAME);
+		fi.setFile(path_name, "session." PROJECT_NAME);
 	if (fi.exists()) {
 		const QString& sFilename = fi.absoluteFilePath();
 		if (m_pWidget) {
@@ -1142,9 +1141,8 @@ void samplv1_jack_application::saveSession (void)
 
 //	const QString& client_name = m_pNsmClient->client_name();
 	const QString& path_name = m_pNsmClient->path_name();
-//	const QString& display_name = m_pNsmClient->display_name();
-//	const QFileInfo fi(path_name, display_name + '.' + PROJECT_NAME);
-	const QFileInfo fi(path_name, "session." PROJECT_NAME);
+	const QString& display_name = m_pNsmClient->display_name();
+	QFileInfo fi(path_name, display_name + '.' + PROJECT_NAME);
 
 	const bool bSave
 		= samplv1_param::savePreset(m_pSampl, fi.absoluteFilePath(), true);
@@ -1153,6 +1151,11 @@ void samplv1_jack_application::saveSession (void)
 		? samplv1_nsm::ERR_OK
 		: samplv1_nsm::ERR_GENERAL);
 	m_pNsmClient->dirty(false);
+
+	fi.setFile(path_name, "session." PROJECT_NAME);
+	if (fi.exists())
+		QFile::remove(fi.absoluteFilePath());
+
 }
 
 
